==> dep-0.16.0.tgz: package/CODE_OF_CONDUCT.md <==
# Code of Conduct

### Table of Contents
1. <a href="#1-respect-others">Respect others.</a>
2. <a href="#2-use-positive-words">Use positive words.</a>
3. <a href="#3-enjoy-this-moment">Enjoy this moment.</a>

## The three things

### 1. Respect others
Everyone has their good points beyond your imagination. It is rare that imagination protrudes its own experience. Let's respect the others by thinking that there is something that can be seen and not seen. There may be people who can not respect, but you do not know it.

### 2. Use positive words
It's better not to prattle on about meaningless things.

We have a passion for the same field, but our backgrounds where we were born and raised are disjointed. There is a culture that says straight. There is a culture that beats around the bush. There is a culture compares an opion to something. There is a culture that makes sarcastic to tell something. I think of the differences as an impossible thing to bridge the difference. So let's use a positive word at least. Let's say thank you to people who took their time for making improvements.


Also in the case of opposing opinions, let's use positive expressions too. That's true sometimes your opinion does not pass, but there is nothing to be pessimistic about. The scope of this project is small and the code base is also small. At such 
times, your can fork and modify by yourself. There is a MIT lisence for you.

### 3. Enjoy this moment
If you get bored with working on this project, let's go away. As long as you do something in this project, let's enjoy with all people in the project. We spend our spare time and are moving forward with the project. I hope that all of the time is worthwhile and that we can get something good experience through development throughout the project.

---
If you think that you can improve this Code Of Conduct, please drop your opinion on the repository. In that case also, please do not forget the three above.

Thanks for reading this docs <3

==> dep-0.18.2.tgz: package/CODE_OF_CONDUCT.md <==
# Code of Conduct

### Table of Contents
1. <a href="#1-respect-others">Respect others.</a>
2. <a href="#2-use-positive-words">Use positive words.</a>
3. <a href="#3-enjoy-this-moment">Enjoy this moment.</a>

## The three things

### 1. Respect others
Everyone has their good points beyond your imagination. It is rare that imagination protrudes its own experience. Let's respect the others by thinking that there is something that can be seen and not seen. There may be people who can not respect, but you do not know it.

### 2. Use positive words
It's better not to prattle on about meaningless things.

We have a passion for the same field, but our backgrounds where we were born and raised are disjointed. There is a culture that says straight. There is a culture that beats around the bush. There is a culture compares an opinion to something. There is a culture that makes sarcastic to tell something. I think of the differences as an impossible thing to bridge the difference. So let's use a positive word at least. Let's say thank you to people who took their time for making improvements.


Also in the case of opposing opinions, let's use positive expressions too. That's true sometimes your opinion does not pass, but there is nothing to be pessimistic about. The scope of this project is small and the code base is also small. At such
times, your can fork and modify by yourself. There is a MIT lisence for you.

### 3. Enjoy this moment
If you get bored with working on this project, let's go away. As long as you do something in this project, let's enjoy with all people in the project. We spend our spare time and are moving forward with the project. I hope that all of the time is worthwhile and that we can get something good experience through development throughout the project.

---
If you think that you can improve this Code Of Conduct, please drop your opinion on the repository. In that case also, please do not forget the three above.

Thanks for reading this docs <3
